********************************
Streams (generic high-level API)
********************************

.. currentmodule:: gruvi

Streams provide a generic, high-level API to work with connection-oriented
transports using file-like, blocking and flow-controlled API.

Utility classes
===============

.. autoclass:: gruvi.StreamBuffer
    :members:

.. autoclass:: gruvi.Stream
    :members:

Stream Protocol
===============

.. autoclass:: gruvi.StreamProtocol
    :members:

Stream Client and Server
========================

.. autoclass:: gruvi.StreamClient
    :members:

.. autoclass:: gruvi.StreamServer
    :members:
